@@ -213,7 +213,8 @@ public:
 	
 	QSet<int> inactiveActivities;
 	
-	Matrix1D<QList<int> > activitiesForSubject;
+	Matrix1D<QList<int> > activitiesForSubjectList;
+	Matrix1D<QSet<int> > activitiesForSubjectSet;
 	Matrix1D<QList<int> > activitiesForActivityTagList;
 	Matrix1D<QSet<int> > activitiesForActivityTagSet;
 
@@ -736,6 +737,9 @@ public:
 	
 	int deactivateActivityTag(const QString& activityTagName);
 	
+	void makeActivityTagPrintable(const QString& activityTagName);
+	void makeActivityTagNotPrintable(const QString& activityTagName);
+	
 	void updateActivitiesWhenRemovingStudents(const QSet<StudentsSet*>& studentsSets, bool updateConstraints);
 	void updateGroupActivitiesInInitialOrderAfterRemoval();
 	void updateConstraintsAfterRemoval();
