@@ -47,9 +47,9 @@ public:
 	QHash <QString, int> studentsTotalNumberOfHours2;
 	QHash <QString, int> subjectsTotalNumberOfHours;
 	QHash <QString, int> subjectsTotalNumberOfHours4;
-	QStringList allStudentsNames;				//NOT QSet <QString>!!! Because that do an incorrect order of the lists!
-	QStringList allTeachersNames;				//NOT QSet <QString>!!! Because that do an incorrect order of the lists!
-	QStringList allSubjectsNames;				//NOT QSet <QString>!!! Because that do an incorrect order of the lists!
+	QStringList allStudentsNames;				//NOT QSet <QString>!!! Because that does an incorrect order of the lists!
+	QStringList allTeachersNames;				//NOT QSet <QString>!!! Because that does an incorrect order of the lists!
+	QStringList allSubjectsNames;				//NOT QSet <QString>!!! Because that does an incorrect order of the lists!
 	QMultiHash <QString, int> studentsActivities;
 	QMultiHash <QString, int> teachersActivities;
 	QMultiHash <QString, int> subjectsActivities;
