@@ -20,6 +20,7 @@
 
 Subject::Subject()
 {
+	comments=QString("");
 }
 
 Subject::~Subject()
@@ -30,11 +31,23 @@ QString Subject::getXmlDescription()
 {
 	QString s="<Subject>\n";
 	s+="	<Name>"+protect(this->name)+"</Name>\n";
+	s+="	<Comments>"+protect(comments)+"</Comments>\n";
 	s+="</Subject>\n";
 
 	return s;
 }
 
+QString Subject::getDescription()
+{
+	QString s=tr("N:%1", "The name of the subject").arg(name);
+	
+	QString end=QString("");
+	if(!comments.isEmpty())
+		end=", "+tr("C: %1", "Comments").arg(comments);
+	
+	return s+end;
+}
+
 QString Subject::getDetailedDescription()
 {
 	QString s=tr("Subject");
@@ -42,6 +55,12 @@ QString Subject::getDetailedDescription()
 	s+=tr("Name=%1", "The name of the subject").arg(this->name);
 	s+="\n";
 
+	//Has comments?
+	if(!comments.isEmpty()){
+		s+=tr("Comments=%1").arg(comments);
+		s+="\n";
+	}
+
 	return s;
 }
 
