@@ -35,6 +35,8 @@ AddConstraintTwoActivitiesConsecutiveForm::AddConstraintTwoActivitiesConsecutive
 	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 
+	connect(swapPushButton, SIGNAL(clicked()), this, SLOT(swap()));
+
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
 	
@@ -228,3 +230,11 @@ void AddConstraintTwoActivitiesConsecutiveForm::addCurrentConstraint()
 		delete ctr;
 	}
 }
+
+void AddConstraintTwoActivitiesConsecutiveForm::swap()
+{
+	int t1=firstActivitiesComboBox->currentIndex();
+	int t2=secondActivitiesComboBox->currentIndex();
+	firstActivitiesComboBox->setCurrentIndex(t2);
+	secondActivitiesComboBox->setCurrentIndex(t1);
+}
