@@ -58,9 +58,12 @@ static QSet<QString> languagesSet;
 #include "helpinstructionsform.h"
 
 #include "timetableshowconflictsform.h"
-#include "timetableviewstudentsform.h"
-#include "timetableviewteachersform.h"
-#include "timetableviewroomsform.h"
+#include "timetableviewstudentsdayshorizontalform.h"
+#include "timetableviewstudentstimehorizontalform.h"
+#include "timetableviewteachersdayshorizontalform.h"
+#include "timetableviewteacherstimehorizontalform.h"
+#include "timetableviewroomsdayshorizontalform.h"
+#include "timetableviewroomstimehorizontalform.h"
 #endif
 
 #include <QCoreApplication>
@@ -199,7 +202,7 @@ void usage(QTextStream* out, const QString& error)
 		"y is integer (seconds) (default 2000000000, which is practically infinite).\n"
 		"z is integer from 0 to 7 and represents the detail level for the generated HTML timetables "
 		"(default 2, larger values have more details/facilities and larger file sizes).\n"
-		"t is one of en_US, ar, ca, cs, da, de, el, es, eu, fa, fr, gl, he, hu, id, it, lt, mk, ms, nl, pl, pt_BR, ro, ru, si, sk, sq, sr, tr, uk, "
+		"t is one of ar, ca, cs, da, de, el, en_GB, en_US, es, eu, fa, fr, gl, he, hu, id, it, lt, mk, ms, nl, pl, pt_BR, ro, ru, si, sk, sq, sr, tr, uk, "
 		"uz, vi, zh_CN, zh_TW (default en_US).\n"
 		"wt1 to wt15 are either true or false and represent whether you want the corresponding timetables to be written on the disk (default true).\n"
 		"a is either true or false and represets if you want activity tags to be present in the final HTML timetables (default true).\n"
@@ -231,7 +234,8 @@ void usage(QTextStream* out, const QString& error)
 		"(If you specify the --version argument, FET just prints version number on the command line prompt and in the output directory and exits.)\n"
 		"\n"
 		"You can ask the FET command line process to stop the timetable generation, by sending it the SIGTERM signal. "
-		"FET will then write the current timetable and the highest stage timetable and exit."
+		"FET will then write the current timetable and the highest stage timetable and exit. "
+		"(If you send the FET command line the SIGKILL signal it will stop immediately, without writing the timetable.)"
 	);
 	
 	cout<<qPrintable(s)<<endl;
@@ -446,11 +450,12 @@ void initLanguagesSet()
 {
 	//This is one of the two places to insert a new language in the sources (the other one is in fetmainform.cpp).
 	languagesSet.clear();
-	languagesSet.insert("en_US");
 	languagesSet.insert("ar");
 	languagesSet.insert("ca");
 	languagesSet.insert("de");
 	languagesSet.insert("el");
+	languagesSet.insert("en_GB");
+	languagesSet.insert("en_US");
 	languagesSet.insert("es");
 	languagesSet.insert("fr");
 	languagesSet.insert("hu");
@@ -552,9 +557,9 @@ void setLanguage(QCoreApplication& qapplication, QWidget* parent)
 	else if(FET_LANGUAGE=="zh_TW"){
 		LANGUAGE_FOR_HTML="zh-Hant";
 	}
-	else if(FET_LANGUAGE=="en_US"){
+	/*else if(FET_LANGUAGE=="en_US"){
 		LANGUAGE_FOR_HTML=FET_LANGUAGE.left(2);
-	}
+	}*/
 	else{
 		LANGUAGE_FOR_HTML=FET_LANGUAGE;
 		LANGUAGE_FOR_HTML.replace(QString("_"), QString("-"));
@@ -611,24 +616,45 @@ void setLanguage(QCoreApplication& qapplication, QWidget* parent)
 			//////
 			
 			//timetable
-			TimetableViewStudentsForm* vsf=qobject_cast<TimetableViewStudentsForm*>(wi);
-			if(vsf!=NULL){
-				vsf->retranslateUi(vsf);
-				vsf->updateStudentsTimetableTable();
+			TimetableViewStudentsDaysHorizontalForm* vsdf=qobject_cast<TimetableViewStudentsDaysHorizontalForm*>(wi);
+			if(vsdf!=NULL){
+				vsdf->retranslateUi(vsdf);
+				vsdf->updateStudentsTimetableTable();
 				continue;
 			}
 
-			TimetableViewTeachersForm* vtchf=qobject_cast<TimetableViewTeachersForm*>(wi);
-			if(vtchf!=NULL){
-				vtchf->retranslateUi(vtchf);
-				vtchf->updateTeachersTimetableTable();
+			TimetableViewStudentsTimeHorizontalForm* vstf=qobject_cast<TimetableViewStudentsTimeHorizontalForm*>(wi);
+			if(vstf!=NULL){
+				vstf->retranslateUi(vstf);
+				vstf->updateStudentsTimetableTable();
 				continue;
 			}
 
-			TimetableViewRoomsForm* vrf=qobject_cast<TimetableViewRoomsForm*>(wi);
-			if(vrf!=NULL){
-				vrf->retranslateUi(vrf);
-				vrf->updateRoomsTimetableTable();
+			TimetableViewTeachersDaysHorizontalForm* vtchdf=qobject_cast<TimetableViewTeachersDaysHorizontalForm*>(wi);
+			if(vtchdf!=NULL){
+				vtchdf->retranslateUi(vtchdf);
+				vtchdf->updateTeachersTimetableTable();
+				continue;
+			}
+
+			TimetableViewTeachersTimeHorizontalForm* vtchtf=qobject_cast<TimetableViewTeachersTimeHorizontalForm*>(wi);
+			if(vtchtf!=NULL){
+				vtchtf->retranslateUi(vtchtf);
+				vtchtf->updateTeachersTimetableTable();
+				continue;
+			}
+
+			TimetableViewRoomsDaysHorizontalForm* vrdf=qobject_cast<TimetableViewRoomsDaysHorizontalForm*>(wi);
+			if(vrdf!=NULL){
+				vrdf->retranslateUi(vrdf);
+				vrdf->updateRoomsTimetableTable();
+				continue;
+			}
+
+			TimetableViewRoomsTimeHorizontalForm* vrtf=qobject_cast<TimetableViewRoomsTimeHorizontalForm*>(wi);
+			if(vrtf!=NULL){
+				vrtf->retranslateUi(vrtf);
+				vrtf->updateRoomsTimetableTable();
 				continue;
 			}
 
@@ -714,9 +740,9 @@ int main(int argc, char **argv)
 
 	terminateGeneratePointer=NULL;
 	
-	students_schedule_ready=0;
-	teachers_schedule_ready=0;
-	rooms_schedule_ready=0;
+	students_schedule_ready=false;
+	teachers_schedule_ready=false;
+	rooms_schedule_ready=false;
 
 #ifndef FET_COMMAND_LINE
 	QObject::connect(&qapplication, SIGNAL(lastWindowClosed()), &qapplication, SLOT(quit()));
