@@ -83,7 +83,7 @@ class FetMainForm: public QMainWindow, public Ui::FetMainForm_template
 	Q_OBJECT
 	
 private:
-	QSpinBox communicationSpinBox;
+//	QSpinBox communicationSpinBox;
 	
 	QMenu* shortcutBasicMenu;
 	QMenu* shortcutDataSpaceMenu;
@@ -337,9 +337,12 @@ public slots:
 	void on_helpAddressesAction_triggered();
 
 	void on_timetableGenerateAction_triggered();
-	void on_timetableViewStudentsAction_triggered();
-	void on_timetableViewTeachersAction_triggered();
-	void on_timetableViewRoomsAction_triggered();
+	void on_timetableViewStudentsDaysHorizontalAction_triggered();
+	void on_timetableViewStudentsTimeHorizontalAction_triggered();
+	void on_timetableViewTeachersDaysHorizontalAction_triggered();
+	void on_timetableViewTeachersTimeHorizontalAction_triggered();
+	void on_timetableViewRoomsDaysHorizontalAction_triggered();
+	void on_timetableViewRoomsTimeHorizontalAction_triggered();
 	void on_timetableShowConflictsAction_triggered();
 	void on_timetablePrintAction_triggered();
 	void on_timetableGenerateMultipleAction_triggered();
